==> syncope-2.1.3-source-release.zip: syncope-2.1.3/ext/flowable/rest-api/src/main/java/org/apache/syncope/common/rest/api/beans/UserRequestQuery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.common.rest.api.beans;

import javax.ws.rs.QueryParam;

public class UserRequestQuery extends AbstractQuery {

    private static final long serialVersionUID = 427312034580076640L;

    public static class Builder extends AbstractQuery.Builder<UserRequestQuery, Builder> {

        @Override
        protected UserRequestQuery newInstance() {
            return new UserRequestQuery();
        }

        public Builder user(final String user) {
            getInstance().setUser(user);
            return this;
        }
    }

    private String user;

    public String getUser() {
        return user;
    }

    @QueryParam("user")
    public void setUser(final String user) {
        this.user = user;
    }
}

==> syncope-3.0.15-source-release.zip: syncope-3.0.15/ext/flowable/rest-api/src/main/java/org/apache/syncope/common/rest/api/beans/UserRequestQuery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.common.rest.api.beans;

import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import javax.ws.rs.QueryParam;
import org.apache.syncope.common.rest.api.service.JAXRSService;

public class UserRequestQuery extends AbstractQuery {

    private static final long serialVersionUID = 427312034580076640L;

    public static class Builder extends AbstractQuery.Builder<UserRequestQuery, Builder> {

        @Override
        protected UserRequestQuery newInstance() {
            return new UserRequestQuery();
        }

        public Builder user(final String user) {
            getInstance().setUser(user);
            return this;
        }
    }

    private String user;

    @Parameter(name = JAXRSService.PARAM_USER, description = "user to match either by key or username", schema =
            @Schema(implementation = String.class, example = "50592942-73ec-44c4-a377-e859524245e4"))
    public String getUser() {
        return user;
    }

    @QueryParam(JAXRSService.PARAM_USER)
    public void setUser(final String user) {
        this.user = user;
    }
}
